@@ -17,15 +17,26 @@ func TestRepoName(t *testing.T) {
 	require.Equal(t, "goreleaser/goreleaser", repo.String())
 }
 
+func TestRepoNameWithDifferentRemote(t *testing.T) {
+	testlib.Mktmp(t)
+	testlib.GitInit(t)
+	testlib.GitRemoteAddWithName(t, "upstream", "https://github.com/goreleaser/goreleaser.git")
+	_, err := git.Run("pull", "upstream", "master")
+	require.NoError(t, err)
+	_, err = git.Run("branch", "--set-upstream-to", "upstream/master")
+	require.NoError(t, err)
+	repo, err := git.ExtractRepoFromConfig()
+	require.NoError(t, err)
+	require.Equal(t, "goreleaser/goreleaser", repo.String())
+}
+
 func TestExtractRepoFromURL(t *testing.T) {
 	// valid urls
 	for _, url := range []string{
 		"git@github.com:goreleaser/goreleaser.git",
 		"git@custom:goreleaser/goreleaser.git",
-		"git@custom:crazy/url/goreleaser/goreleaser.git",
 		"https://github.com/goreleaser/goreleaser.git",
 		"https://github.enterprise.com/goreleaser/goreleaser.git",
-		"https://github.enterprise.com/crazy/url/goreleaser/goreleaser.git",
 	} {
 		t.Run(url, func(t *testing.T) {
 			repo, err := git.ExtractRepoFromURL(url)
@@ -34,6 +45,18 @@ func TestExtractRepoFromURL(t *testing.T) {
 		})
 	}
 
+	// nested urls
+	for _, url := range []string{
+		"git@custom:group/nested/goreleaser/goreleaser.git",
+		"https://gitlab.mycompany.com/group/nested/goreleaser/goreleaser.git",
+	} {
+		t.Run(url, func(t *testing.T) {
+			repo, err := git.ExtractRepoFromURL(url)
+			require.NoError(t, err)
+			require.Equal(t, "group/nested/goreleaser/goreleaser", repo.String())
+		})
+	}
+
 	// invalid urls
 	for _, url := range []string{
 		"git@gist.github.com:someid.git",
