@@ -5,6 +5,7 @@ package blob
 // the test setup and teardown
 
 import (
+	"fmt"
 	"io"
 	"net"
 	"os"
@@ -21,6 +22,11 @@ import (
 	"gocloud.dev/blob"
 )
 
+const (
+	minioUser = "minio"
+	minioPwd  = "miniostorage"
+)
+
 func TestMinioUpload(t *testing.T) {
 	listen := randomListen(t)
 	folder := t.TempDir()
@@ -200,75 +206,6 @@ func TestMinioUploadInvalidCustomBucketID(t *testing.T) {
 	require.Error(t, Pipe{}.Publish(ctx))
 }
 
-func TestMinioUploadSkipPublish(t *testing.T) {
-	listen := randomListen(t)
-	folder := t.TempDir()
-	srcpath := filepath.Join(folder, "source.tar.gz")
-	tgzpath := filepath.Join(folder, "bin.tar.gz")
-	debpath := filepath.Join(folder, "bin.deb")
-	checkpath := filepath.Join(folder, "check.txt")
-	require.NoError(t, os.WriteFile(checkpath, []byte("fake checksums"), 0o744))
-	require.NoError(t, os.WriteFile(srcpath, []byte("fake\nsrc"), 0o744))
-	require.NoError(t, os.WriteFile(tgzpath, []byte("fake\ntargz"), 0o744))
-	require.NoError(t, os.WriteFile(debpath, []byte("fake\ndeb"), 0o744))
-	ctx := context.New(config.Project{
-		Dist:        folder,
-		ProjectName: "testupload",
-		Blobs: []config.Blob{
-			{
-				Provider: "s3",
-				Bucket:   "test",
-				Region:   "us-east",
-				Endpoint: "http://" + listen,
-				IDs:      []string{"foo", "bar"},
-			},
-		},
-	})
-	ctx.SkipPublish = true
-	ctx.Git = context.GitInfo{CurrentTag: "v1.2.0"}
-	ctx.Artifacts.Add(&artifact.Artifact{
-		Type: artifact.Checksum,
-		Name: "checksum.txt",
-		Path: checkpath,
-	})
-	ctx.Artifacts.Add(&artifact.Artifact{
-		Type: artifact.UploadableSourceArchive,
-		Name: "source.tar.gz",
-		Path: srcpath,
-		Extra: map[string]interface{}{
-			"Format": "tar.gz",
-		},
-	})
-	ctx.Artifacts.Add(&artifact.Artifact{
-		Type: artifact.UploadableArchive,
-		Name: "bin.tar.gz",
-		Path: tgzpath,
-		Extra: map[string]interface{}{
-			"ID": "foo",
-		},
-	})
-	ctx.Artifacts.Add(&artifact.Artifact{
-		Type: artifact.LinuxPackage,
-		Name: "bin.deb",
-		Path: debpath,
-		Extra: map[string]interface{}{
-			"ID": "bar",
-		},
-	})
-	name := "test_upload"
-	start(t, name, listen)
-	prepareEnv()
-	require.NoError(t, Pipe{}.Default(ctx))
-	require.NoError(t, Pipe{}.Publish(ctx))
-
-	require.NotContains(t, getFiles(t, ctx, ctx.Config.Blobs[0]), []string{
-		"testupload/v1.2.0/bin.deb",
-		"testupload/v1.2.0/bin.tar.gz",
-		"testupload/v1.2.0/checksum.txt",
-		"testupload/v1.2.0/source.tar.gz",
-	})
-}
-
 func randomListen(t *testing.T) string {
 	t.Helper()
 	listener, err := net.Listen("tcp", "127.0.0.1:0")
@@ -278,36 +215,36 @@ func randomListen(t *testing.T) string {
 }
 
 func prepareEnv() {
-	os.Setenv("AWS_ACCESS_KEY_ID", "minio")
-	os.Setenv("AWS_SECRET_ACCESS_KEY", "miniostorage")
+	os.Setenv("AWS_ACCESS_KEY_ID", minioUser)
+	os.Setenv("AWS_SECRET_ACCESS_KEY", minioPwd)
 	os.Setenv("AWS_REGION", "us-east-1")
 }
 
 func start(tb testing.TB, name, listen string) {
 	tb.Helper()
-	wd, err := os.Getwd()
-	require.NoError(tb, err)
-
-	removeTestData()
 
+	data := filepath.Join(os.TempDir(), name)
 	tb.Cleanup(func() {
+		mc(tb, name, "mc rb --force local/test")
 		if out, err := exec.Command("docker", "stop", name).CombinedOutput(); err != nil {
 			tb.Fatalf("failed to stop minio: %s", string(out))
 		}
-		removeTestData()
+		if err := os.RemoveAll(data); err != nil {
+			tb.Logf("failed to remove %s", data)
+		}
 	})
 
 	if out, err := exec.Command(
 		"docker", "run", "-d", "--rm",
-		"-v", filepath.Join(wd, "testdata/data")+":/data",
+		"-v", data+":/data",
 		"--name", name,
 		"-p", listen+":9000",
-		"-e", "MINIO_ACCESS_KEY=minio",
-		"-e", "MINIO_SECRET_KEY=miniostorage",
+		"-e", "MINIO_ROOT_USER="+minioUser,
+		"-e", "MINIO_ROOT_PASSWORD="+minioPwd,
 		"--health-interval", "1s",
 		"--health-cmd=curl --silent --fail http://localhost:9000/minio/health/ready || exit 1",
 		"minio/minio",
-		"server", "/data",
+		"server", "/data", "--console-address", ":9001",
 	).CombinedOutput(); err != nil {
 		tb.Fatalf("failed to start minio: %s", string(out))
 	}
@@ -323,10 +260,25 @@ func start(tb testing.TB, name, listen string) {
 		}
 		tb.Log("waiting for minio to be healthy")
 	}
+
+	mc(tb, name, "mc mb local/test")
 }
 
-func removeTestData() {
-	_ = os.RemoveAll("./testdata/data/test/testupload") // dont care if it fails
+func mc(tb testing.TB, name, cmd string) {
+	tb.Helper()
+
+	if out, err := exec.Command(
+		"docker", "run", "--rm",
+		"--link", name,
+		"--entrypoint", "sh",
+		"minio/mc",
+		"-c", fmt.Sprintf(
+			"mc config host add local http://%s:9000 %s %s; %s",
+			name, minioUser, minioPwd, cmd,
+		),
+	).CombinedOutput(); err != nil {
+		tb.Fatalf("failed to create test bucket: %s", string(out))
+	}
 }
 
 func getFiles(t *testing.T, ctx *context.Context, cfg config.Blob) []string {
