@@ -7,7 +7,9 @@ import (
 	"strings"
 
 	"github.com/goreleaser/goreleaser/internal/client"
-	"github.com/goreleaser/goreleaser/internal/middleware"
+	"github.com/goreleaser/goreleaser/internal/middleware/errhandler"
+	"github.com/goreleaser/goreleaser/internal/middleware/logging"
+	"github.com/goreleaser/goreleaser/internal/middleware/skip"
 	"github.com/goreleaser/goreleaser/internal/tmpl"
 	"github.com/goreleaser/goreleaser/pkg/context"
 	"github.com/goreleaser/goreleaser/pkg/defaults"
@@ -16,9 +18,7 @@ import (
 // Pipe that sets the defaults.
 type Pipe struct{}
 
-func (Pipe) String() string {
-	return "setting defaults"
-}
+func (Pipe) String() string { return "setting defaults" }
 
 // Run the pipe.
 func (Pipe) Run(ctx *context.Context) error {
@@ -40,10 +40,13 @@ func (Pipe) Run(ctx *context.Context) error {
 		ctx.Config.GiteaURLs.Download = strings.ReplaceAll(apiURL, "/api/v1", "")
 	}
 	for _, defaulter := range defaults.Defaulters {
-		if err := middleware.Logging(
-			defaulter.String(),
-			middleware.ErrHandler(defaulter.Default),
-			middleware.ExtraPadding,
+		if err := skip.Maybe(
+			defaulter,
+			logging.Log(
+				defaulter.String(),
+				errhandler.Handle(defaulter.Default),
+				logging.ExtraPadding,
+			),
 		)(ctx); err != nil {
 			return err
 		}
