@@ -578,7 +578,7 @@ type Filters struct {
 type Changelog struct {
 	Filters Filters `yaml:",omitempty"`
 	Sort    string  `yaml:",omitempty"`
-	Skip    bool    `yaml:",omitempty"`
+	Skip    bool    `yaml:",omitempty"` // TODO(caarlos0): rename to Disable to match other pipes
 }
 
 // EnvFiles holds paths to files that contains environment variables
@@ -696,6 +696,7 @@ type Announce struct {
 	Slack   Slack   `yaml:"slack,omitempty"`
 	Discord Discord `yaml:"discord,omitempty"`
 	Teams   Teams   `yaml:"teams,omitempty"`
+	SMTP    SMTP    `yaml:"smtp,omitempty"`
 }
 
 type Twitter struct {
@@ -737,6 +738,18 @@ type Teams struct {
 	IconURL         string `yaml:"icon_url,omitempty"`
 }
 
+type SMTP struct {
+	Enabled            bool     `yaml:"enabled,omitempty"`
+	Host               string   `yaml:"host,omitempty"`
+	Port               int      `yaml:"port,omitempty"`
+	Username           string   `yaml:"username,omitempty"`
+	From               string   `yaml:"from,omitempty"`
+	To                 []string `yaml:"to,omitempty"`
+	SubjectTemplate    string   `yaml:"subject_template,omitempty"`
+	BodyTemplate       string   `yaml:"body_template,omitempty"`
+	InsecureSkipVerify bool     `yaml:"insecure_skip_verify,omitempty"`
+}
+
 // Load config file.
 func Load(file string) (config Project, err error) {
 	f, err := os.Open(file) // #nosec
